#!/usr/bin/ruby

require 'json'


module Edj
	class Item
		def self.from(hash)
			case hash["event"]
			when "Scan"
				ScanItem.new(hash)
			when "EngineerProgress"
				EngineerProgressItem.new(hash)
			when "EngineerContributionItem"
				EngineerContributionItem.new(hash)
			end
		end

		def initialize(hash)
			@raw = hash
		end

		def timestamp()
			@raw["timestamp"]
		end
	end

	class Journal
		attr_reader :tree

		def initialize(f)
			@f = f
			@tree = {}
		end

		def filter(type)
			File.open(@f).readlines
				.map {|line| Item.from(JSON.parse(line))}
				.select {|item| item.is_a? type }
		end

		def scan_value()
			total_value = 0
			File.open(@f).each do |line|
				item = Item.from(JSON.parse(line))
				if item.is_a? ScanItem then
					v = item.value
					bits = item.bodyName.split(' ')
					(1..(bits.size-1)).each do |i|
						entry = bits[0..i].join(' ')
						o = @tree[entry]
						@tree[entry] ||= 0
						@tree[entry] += v
					end
					STDOUT.puts("#{item.timestamp} #{item.bodyName} --> #{v}")
					total_value = total_value + v
				end
			end
			total_value
		end
	end
end

